// Software fr Pollins "Ampelsteuerung"
//
// Die Ports PD04 und PD03 werden zum Schalten von IR-LEDs verwendet,
// mit denen die Linienfolger-Fahrzeuge an der Ampel automatisch
// wieder anfahren knnen.

#include <avr/io.h>
#include <stdlib.h>
#include <util/delay.h>

#define TRUE 1
#define FALSE 0
#define LANGPHASE 6
#define KURZPHASE 2
#define BLINKEN 1

// Belegung der PORTs
// A = Autoampel, F = Fugngerampel, IR = IR-LEDs fr automatisches Anfahren vor der Ampel
//
// Port B:
// PB07=A1ROT PB06=A1GELB PB05=A1GRUEN PB04=A2ROT PB03=A2GELB PB02=A2GRUEN PB01=F1ROT PB00=F1GRUEN 
//
// Port D:
// PD06=F2ROT PD05=F2GRUEN PD04=IR1 PD03=IR2 PD02=FREI
// 
// Beispiel -> Einschalten F2GRUEN -> 0b00100000

//Funktion zum abfragen des Zustands des Tasters1
int taster1(void)
{
 

    if (PINA & (1<<PINA0))
        {
            return 1;
        }
        else
        {
            return 0;
        }
   
}

//Funktion zum abfragen des Zustands des Tasters2
int taster2(void)
{
 

    if (PINA & (1<<PINA1))
        {
            return TRUE;
        }
        else
        {
            return FALSE;
        }
   
}

//Funktion fr Sekunden-Verzgerung
int delay_sec(int Sekunden)
{
    for (int i=0; i<Sekunden; i++)
    {
        _delay_ms(4000);
    }
    return 0;
}


int main (void) {

    DDRD = 0xFF;
    DDRB = 0xFF;
    DDRA &= ~((1 << DDB0) | (1 << DDB1)); // Pin4 und Pins5 (Taster 1 und 2) als Eingnge setzen
 
   
    while (1)
        {
		
        if (taster1() == TRUE)
            {
			// Tagschaltung:
			// Phase 1
			PORTB = (0b10000101);
			PORTD = (0b01001000);
			delay_sec(LANGPHASE);
			
			// Phase 2
			PORTB = (0b11001010);
			PORTD = (0b01000000);
			delay_sec(KURZPHASE);
			
			// Phase 3
			PORTB = (0b00110010);
			PORTD = (0b00110000);
			delay_sec(LANGPHASE);
			
			// Phase 4
			PORTB = (0b01011010);
			PORTD = (0b01000000);
			delay_sec(KURZPHASE);
            }
			else
			{
			// Nachtschaltung Gelb-Blinken
			PORTB = (0b01001000);
			PORTD = (0b00000000);
			delay_sec(BLINKEN);
			PORTB = (0b00000000);
			delay_sec(BLINKEN);
			}
        }
    return 0;
   
}